@@ -132,11 +132,11 @@ switch ($action) {
             
             // Create site record
             $stmt = $db->prepare("
-                INSERT INTO whp.sites (site_name, primary_domain_id, container_type_id, container_count, cpu_per_container, memory_per_container, username, enable_ssl, auto_recreate_containers, created_at) 
+                INSERT INTO whp.sites (site_name, primary_domain_id, container_type_id, container_count, cpu_per_container, memory_per_container, username, ssl_enabled, auto_recreate_on_update, created_at) 
                 VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW())
             ");
             
-            $enable_ssl = isset($_POST['enable_ssl']) && $_POST['enable_ssl'] == '1' ? 1 : 0;
+            $ssl_enabled = isset($_POST['enable_ssl']) && $_POST['enable_ssl'] == '1' ? 1 : 0;
             $auto_recreate = isset($_POST['auto_recreate_containers']) && $_POST['auto_recreate_containers'] == '1' ? 1 : 0;
             
             $stmt->execute([
@@ -147,7 +147,7 @@ switch ($action) {
                 $cpu_per_container, 
                 $memory_per_container, 
                 $primary_domain_row['username'], 
-                $enable_ssl, 
+                $ssl_enabled, 
                 $auto_recreate
             ]);
             
@@ -199,7 +199,7 @@ switch ($action) {
                 'container_count' => $container_count,
                 'cpu_per_container' => $cpu_per_container,
                 'memory_per_container' => $memory_per_container,
-                'enable_ssl' => $enable_ssl,
+                'enable_ssl' => $ssl_enabled,
                 'additional_domains' => $additional_domains_added
             ];
             
